# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'LiveTimestamps_tab_c.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(874, 636)
        self.gridLayout_2 = QtWidgets.QGridLayout(Form)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.frame_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame_2)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_comboBox_mask_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mask_2.setEnabled(True)
        self.label_comboBox_mask_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mask_2.setFont(font)
        self.label_comboBox_mask_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_comboBox_mask_2.setObjectName("label_comboBox_mask_2")
        self.horizontalLayout_7.addWidget(self.label_comboBox_mask_2)
        self.comboBox_mask_2 = QtWidgets.QComboBox(self.frame_2)
        self.comboBox_mask_2.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_mask_2.sizePolicy().hasHeightForWidth())
        self.comboBox_mask_2.setSizePolicy(sizePolicy)
        self.comboBox_mask_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_mask_2.setFont(font)
        self.comboBox_mask_2.setObjectName("comboBox_mask_2")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.comboBox_mask_2.addItem("")
        self.horizontalLayout_7.addWidget(self.comboBox_mask_2)
        self.verticalLayout.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayout_8.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_8.setSpacing(6)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_comboBox_mb_2 = QtWidgets.QLabel(self.frame_2)
        self.label_comboBox_mb_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_comboBox_mb_2.setFont(font)
        self.label_comboBox_mb_2.setObjectName("label_comboBox_mb_2")
        self.horizontalLayout_8.addWidget(self.label_comboBox_mb_2)
        self.comboBox_mb_2 = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_mb_2.sizePolicy().hasHeightForWidth())
        self.comboBox_mb_2.setSizePolicy(sizePolicy)
        self.comboBox_mb_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_mb_2.setFont(font)
        self.comboBox_mb_2.setObjectName("comboBox_mb_2")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.comboBox_mb_2.addItem("")
        self.horizontalLayout_8.addWidget(self.comboBox_mb_2)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_FW_2 = QtWidgets.QLabel(self.frame_2)
        self.label_FW_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_FW_2.setFont(font)
        self.label_FW_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_FW_2.setObjectName("label_FW_2")
        self.horizontalLayout_9.addWidget(self.label_FW_2)
        self.comboBox_FW_2 = QtWidgets.QComboBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_FW_2.sizePolicy().hasHeightForWidth())
        self.comboBox_FW_2.setSizePolicy(sizePolicy)
        self.comboBox_FW_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.comboBox_FW_2.setFont(font)
        self.comboBox_FW_2.setObjectName("comboBox_FW_2")
        self.comboBox_FW_2.addItem("")
        self.comboBox_FW_2.addItem("")
        self.comboBox_FW_2.addItem("")
        self.horizontalLayout_9.addWidget(self.comboBox_FW_2)
        self.verticalLayout.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.label_timestamps_2 = QtWidgets.QLabel(self.frame_2)
        self.label_timestamps_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_timestamps_2.setFont(font)
        self.label_timestamps_2.setLineWidth(0)
        self.label_timestamps_2.setTextFormat(QtCore.Qt.PlainText)
        self.label_timestamps_2.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_timestamps_2.setObjectName("label_timestamps_2")
        self.horizontalLayout_11.addWidget(self.label_timestamps_2)
        self.spinBox_timestamps_2 = QtWidgets.QSpinBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_timestamps_2.sizePolicy().hasHeightForWidth())
        self.spinBox_timestamps_2.setSizePolicy(sizePolicy)
        self.spinBox_timestamps_2.setMinimumSize(QtCore.QSize(100, 0))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.spinBox_timestamps_2.setFont(font)
        self.spinBox_timestamps_2.setMaximum(1536)
        self.spinBox_timestamps_2.setProperty("value", 300)
        self.spinBox_timestamps_2.setObjectName("spinBox_timestamps_2")
        self.horizontalLayout_11.addWidget(self.spinBox_timestamps_2)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.checkBox_pix_add_fix = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_pix_add_fix.setFont(font)
        self.checkBox_pix_add_fix.setObjectName("checkBox_pix_add_fix")
        self.verticalLayout.addWidget(self.checkBox_pix_add_fix)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setContentsMargins(-1, 0, -1, 0)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.checkBox_presetMask_2 = QtWidgets.QCheckBox(self.frame_2)
        self.checkBox_presetMask_2.setEnabled(True)
        self.checkBox_presetMask_2.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_presetMask_2.setFont(font)
        self.checkBox_presetMask_2.setObjectName("checkBox_presetMask_2")
        self.horizontalLayout_10.addWidget(self.checkBox_presetMask_2)
        self.label_presetMaskInfo_2 = QtWidgets.QLabel(self.frame_2)
        self.label_presetMaskInfo_2.setMinimumSize(QtCore.QSize(20, 20))
        self.label_presetMaskInfo_2.setMaximumSize(QtCore.QSize(20, 20))
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(160, 226, 227))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(227, 227, 227))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(173, 240, 240))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(247, 247, 247))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(178, 219, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        self.label_presetMaskInfo_2.setPalette(palette)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_presetMaskInfo_2.setFont(font)
        self.label_presetMaskInfo_2.setCursor(QtGui.QCursor(QtCore.Qt.WhatsThisCursor))
        self.label_presetMaskInfo_2.setAutoFillBackground(True)
        self.label_presetMaskInfo_2.setFrameShape(QtWidgets.QFrame.Box)
        self.label_presetMaskInfo_2.setTextFormat(QtCore.Qt.AutoText)
        self.label_presetMaskInfo_2.setScaledContents(False)
        self.label_presetMaskInfo_2.setAlignment(QtCore.Qt.AlignCenter)
        self.label_presetMaskInfo_2.setObjectName("label_presetMaskInfo_2")
        self.horizontalLayout_10.addWidget(self.label_presetMaskInfo_2)
        spacerItem = QtWidgets.QSpacerItem(5, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem)
        self.pushButton_resetMask_2 = QtWidgets.QPushButton(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_resetMask_2.sizePolicy().hasHeightForWidth())
        self.pushButton_resetMask_2.setSizePolicy(sizePolicy)
        self.pushButton_resetMask_2.setMinimumSize(QtCore.QSize(100, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_resetMask_2.setFont(font)
        self.pushButton_resetMask_2.setObjectName("pushButton_resetMask_2")
        self.horizontalLayout_10.addWidget(self.pushButton_resetMask_2)
        self.verticalLayout.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_TopMostPixels = QtWidgets.QLabel(self.frame_2)
        self.label_TopMostPixels.setMinimumSize(QtCore.QSize(0, 26))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_TopMostPixels.setFont(font)
        self.label_TopMostPixels.setObjectName("label_TopMostPixels")
        self.horizontalLayout_2.addWidget(self.label_TopMostPixels)
        self.lcdTopMostPixel1 = QtWidgets.QLCDNumber(self.frame_2)
        self.lcdTopMostPixel1.setObjectName("lcdTopMostPixel1")
        self.horizontalLayout_2.addWidget(self.lcdTopMostPixel1)
        self.lcdTopMostPixel2 = QtWidgets.QLCDNumber(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(8)
        self.lcdTopMostPixel2.setFont(font)
        self.lcdTopMostPixel2.setObjectName("lcdTopMostPixel2")
        self.horizontalLayout_2.addWidget(self.lcdTopMostPixel2)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.scrollArea = QtWidgets.QScrollArea(self.frame_2)
        self.scrollArea.setMinimumSize(QtCore.QSize(0, 250))
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 256, 248))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.scrollArea.setWidget(self.scrollAreaWidgetContents_2)
        self.verticalLayout.addWidget(self.scrollArea)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setContentsMargins(-1, -1, -1, 0)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.checkBox_linearScale_2 = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_linearScale_2.setFont(font)
        self.checkBox_linearScale_2.setChecked(True)
        self.checkBox_linearScale_2.setObjectName("checkBox_linearScale_2")
        self.horizontalLayout_12.addWidget(self.checkBox_linearScale_2)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem1)
        self.checkBox_grouping_2 = QtWidgets.QCheckBox(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.checkBox_grouping_2.setFont(font)
        self.checkBox_grouping_2.setObjectName("checkBox_grouping_2")
        self.horizontalLayout_12.addWidget(self.checkBox_grouping_2)
        self.verticalLayout.addLayout(self.horizontalLayout_12)
        self.pushButton_refreshPlot = QtWidgets.QPushButton(self.frame_2)
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_refreshPlot.setFont(font)
        self.pushButton_refreshPlot.setObjectName("pushButton_refreshPlot")
        self.verticalLayout.addWidget(self.pushButton_refreshPlot)
        self.pushButton_startStream = QtWidgets.QPushButton(self.frame_2)
        self.pushButton_startStream.setMinimumSize(QtCore.QSize(0, 30))
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.pushButton_startStream.setFont(font)
        self.pushButton_startStream.setObjectName("pushButton_startStream")
        self.verticalLayout.addWidget(self.pushButton_startStream)
        self.gridLayout_2.addWidget(self.frame_2, 0, 1, 1, 1)
        self.frame = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame.setObjectName("frame")
        self.gridLayout = QtWidgets.QGridLayout(self.frame)
        self.gridLayout.setObjectName("gridLayout")
        self.pushButton_browse = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_browse.sizePolicy().hasHeightForWidth())
        self.pushButton_browse.setSizePolicy(sizePolicy)
        self.pushButton_browse.setMinimumSize(QtCore.QSize(100, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.pushButton_browse.setFont(font)
        self.pushButton_browse.setObjectName("pushButton_browse")
        self.gridLayout.addWidget(self.pushButton_browse, 0, 0, 1, 2)
        self.label_leftXLim = QtWidgets.QLabel(self.frame)
        self.label_leftXLim.setMinimumSize(QtCore.QSize(0, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_leftXLim.setFont(font)
        self.label_leftXLim.setObjectName("label_leftXLim")
        self.gridLayout.addWidget(self.label_leftXLim, 6, 0, 1, 1)
        self.widget_figure = QtWidgets.QWidget(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.widget_figure.sizePolicy().hasHeightForWidth())
        self.widget_figure.setSizePolicy(sizePolicy)
        self.widget_figure.setMinimumSize(QtCore.QSize(500, 425))
        font = QtGui.QFont()
        font.setPointSize(15)
        self.widget_figure.setFont(font)
        self.widget_figure.setObjectName("widget_figure")
        self.gridLayout.addWidget(self.widget_figure, 1, 0, 1, 3)
        self.horizontalSlider_leftXLim = QtWidgets.QSlider(self.frame)
        self.horizontalSlider_leftXLim.setMinimumSize(QtCore.QSize(0, 28))
        self.horizontalSlider_leftXLim.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_leftXLim.setObjectName("horizontalSlider_leftXLim")
        self.gridLayout.addWidget(self.horizontalSlider_leftXLim, 6, 1, 1, 2)
        self.lineEdit_browse = QtWidgets.QLineEdit(self.frame)
        self.lineEdit_browse.setMinimumSize(QtCore.QSize(0, 28))
        self.lineEdit_browse.setObjectName("lineEdit_browse")
        self.gridLayout.addWidget(self.lineEdit_browse, 0, 2, 1, 1)
        self.label_rightXLim = QtWidgets.QLabel(self.frame)
        self.label_rightXLim.setMinimumSize(QtCore.QSize(0, 28))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.label_rightXLim.setFont(font)
        self.label_rightXLim.setObjectName("label_rightXLim")
        self.gridLayout.addWidget(self.label_rightXLim, 8, 0, 1, 1)
        self.horizontalSlider_rightXLim = QtWidgets.QSlider(self.frame)
        self.horizontalSlider_rightXLim.setMinimumSize(QtCore.QSize(0, 28))
        self.horizontalSlider_rightXLim.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_rightXLim.setObjectName("horizontalSlider_rightXLim")
        self.gridLayout.addWidget(self.horizontalSlider_rightXLim, 8, 1, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem2, 5, 0, 1, 3)
        self.gridLayout_2.addWidget(self.frame, 0, 0, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.label_comboBox_mask_2.setText(_translate("Form", "LinoSPAD2 daughterboard"))
        self.comboBox_mask_2.setItemText(0, _translate("Form", "B7d"))
        self.comboBox_mask_2.setItemText(1, _translate("Form", "NL11"))
        self.comboBox_mask_2.setItemText(2, _translate("Form", "A5"))
        self.comboBox_mask_2.setItemText(3, _translate("Form", "D2b"))
        self.label_comboBox_mb_2.setText(_translate("Form", "LinoSPAD2 motherboard"))
        self.comboBox_mb_2.setItemText(0, _translate("Form", "#28"))
        self.comboBox_mb_2.setItemText(1, _translate("Form", "#33"))
        self.comboBox_mb_2.setItemText(2, _translate("Form", "#21"))
        self.comboBox_mb_2.setItemText(3, _translate("Form", "#36"))
        self.comboBox_mb_2.setItemText(4, _translate("Form", "#37"))
        self.comboBox_mb_2.setItemText(5, _translate("Form", "#4"))
        self.comboBox_mb_2.setItemText(6, _translate("Form", "#29"))
        self.label_FW_2.setText(_translate("Form", "Firmware version"))
        self.comboBox_FW_2.setItemText(0, _translate("Form", "2212b"))
        self.comboBox_FW_2.setItemText(1, _translate("Form", "2208"))
        self.comboBox_FW_2.setItemText(2, _translate("Form", "2212s"))
        self.label_timestamps_2.setToolTip(_translate("Form", "<html><head/><body><p>Number of timestamps per pixel per acquisition cycle. The default is 512.</p></body></html>"))
        self.label_timestamps_2.setText(_translate("Form", "Timestamps"))
        self.checkBox_pix_add_fix.setText(_translate("Form", "Correct pixel addresing"))
        self.checkBox_presetMask_2.setText(_translate("Form", "Preset mask"))
        self.label_presetMaskInfo_2.setToolTip(_translate("Form", "<html><head/><body><p>Mask for warm pixels of a certain LinoSPAD2 board, which can be selected above.</p></body></html>"))
        self.label_presetMaskInfo_2.setText(_translate("Form", "i"))
        self.pushButton_resetMask_2.setText(_translate("Form", "Reset Mask"))
        self.label_TopMostPixels.setText(_translate("Form", "Top-most pixels:"))
        self.checkBox_linearScale_2.setText(_translate("Form", "Linear scale"))
        self.checkBox_grouping_2.setToolTip(_translate("Form", "<html><head/><body><p>Check to plot three vertical lines to help allign the peaks in a single group of 64 pixels.</p></body></html>"))
        self.checkBox_grouping_2.setText(_translate("Form", "Group of 64"))
        self.pushButton_refreshPlot.setText(_translate("Form", "Refresh plot"))
        self.pushButton_startStream.setText(_translate("Form", "Start stream"))
        self.pushButton_browse.setText(_translate("Form", "Browse"))
        self.label_leftXLim.setText(_translate("Form", "Left x limit"))
        self.label_rightXLim.setText(_translate("Form", "Right x limit"))
